@@ -19,7 +19,7 @@ class NewUserActionReadContract(Contract):
 class NewUserActionID(ID):
     _service = SERVICE
     _app = APP
-    _view_set = 'profile'
+    _view_set = 'new_user_action'
 
 
 class NewUserActionPoint(ListPointMixin, CreatePointMixin, ContractPoint):
